package sgc.portal.cw.cw1402.persistence;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cw.cw1402.model.CW14020001U;
import sgc.portal.cw.cw1402.dto.CW14020001USearch;

import java.util.List;

@Mapper
public interface CW14020001UMapper {
	
	
    List<EasyHashMap<String, Object>> getList(CW14020001USearch search);
	
    List<EasyHashMap<String, Object>> getList2(CW14020001USearch search);
	
    List<EasyHashMap<String, Object>> getList3(CW14020001USearch search);

    int insert(CW14020001U cW14020001U);

    int update(CW14020001U cW14020001U);

    int delete(CW14020001U cW14020001U);

	String selectResiNo(CW14020001USearch search);

	String selectResiNo(CW14020001U cW14020001U);

	int selectSeq(CW14020001U cW14020001U);
    
    int updateStatus(CW14020001U cW14020001U);

	int dupChk(CW14020001U cW14020001U);

	int drawChk(CW14020001U cW14020001U);

	int ruleChk(CW14020001U cW14020001U);

	int cancelChk(CW14020001U cW14020001U);
}
